@@ -11,11 +11,8 @@ classes = ["display"]
 style = "max-width:100%"
 
 """Maximum bytes for displaying a table"""
-maxBytes = 2 ** 16
+maxBytes = 2**16
 
 """Maximum number of rows or columns"""
 # maxRows = 10000
 # maxColumns = 1000
-
-"""Default column width for large tables"""
-columnDefs = [{"width": "70px", "targets": "_all"}]
