@@ -1,4 +1,3 @@
-import io
 import os
 
 
@@ -10,5 +9,5 @@ def find_package_file(*path):
 
 def read_package_file(*path):
     """Return the content of a file from the itables package"""
-    with io.open(find_package_file(*path), encoding="utf-8") as fp:
+    with open(find_package_file(*path), encoding="utf-8") as fp:
         return fp.read()
